@@ -103,7 +103,7 @@ main(int argc,
 
     xfce_textdomain(GETTEXT_PACKAGE, LOCALEDIR, "UTF-8");
 
-    if(!gtk_init_with_args (&argc, &argv, "", option_entries,
+    if(!gtk_init_with_args (&argc, &argv, NULL, option_entries,
                             GETTEXT_PACKAGE, &error))
     {
         if(G_LIKELY(error)) {
@@ -119,7 +119,7 @@ main(int argc,
 
     if(G_UNLIKELY(opt_version)) {
         g_print("%s %s (Xfce %s)\n\n", G_LOG_DOMAIN, PACKAGE_VERSION, xfce_version_string ());
-        g_print("%s\n", "Copyright (c) 2004-2014");
+        g_print("%s\n", "Copyright (c) 2004-2020");
         g_print("\t%s\n\n", _("The Xfce development team. All rights reserved."));
         g_print(_("Please report bugs to <%s>."), PACKAGE_BUGREPORT);
         g_print("\n");
@@ -148,9 +148,11 @@ main(int argc,
                                 &error);
 
     if(!builder) {
-        xfce_dialog_show_error(NULL, error,
-                               _("Unable to create user interface from embedded definition data"));
-        g_error_free (error);
+        if (error) {
+            xfce_dialog_show_error(NULL, error,
+                _("Unable to create user interface from embedded definition data"));
+            g_error_free (error);
+        }
         return EXIT_FAILURE;
     }
 
