@@ -41,6 +41,8 @@ static void          xfae_window_item_toggled                 (XfaeWindow
                                                                gchar            *path_string);
 static void          xfae_window_selection_changed            (GtkTreeSelection *selection,
                                                                GtkWidget        *remove_button);
+static void          xfae_window_correct_treeview_column_size (GtkWidget        *treeview,
+                                                               gpointer          user_data);
 static GtkTreeModel* xfae_window_create_run_hooks_combo_model (void);
 
 
@@ -104,6 +106,15 @@ run_hook_changed (GtkCellRenderer *render,
 
 
 
+static void
+xfae_window_correct_treeview_column_size (GtkWidget *treeview,
+                                          gpointer   user_data)
+{
+    gtk_tree_view_columns_autosize (GTK_TREE_VIEW (treeview));
+}
+
+
+
 static void
 xfae_window_init (XfaeWindow *window)
 {
@@ -111,43 +122,17 @@ xfae_window_init (XfaeWindow *window)
   GtkCellRenderer   *renderer;
   GtkTreeModel      *model;
   GtkWidget         *vbox;
-  GtkWidget         *hbox;
   GtkWidget         *img;
-  GtkWidget         *label;
   GtkWidget         *swin;
   GtkWidget         *bbox;
   GtkWidget         *button;
 
-  vbox = GTK_WIDGET(window);
+  vbox = GTK_WIDGET (window);
   gtk_orientable_set_orientation (GTK_ORIENTABLE (vbox),
                                   GTK_ORIENTATION_VERTICAL);
   gtk_box_set_spacing (GTK_BOX (vbox), 0);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
 
-  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
-  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, TRUE, 6);
-  gtk_widget_show (hbox);
-
-  img = gtk_image_new_from_icon_name ("dialog-information", GTK_ICON_SIZE_DIALOG);
-  gtk_box_pack_start (GTK_BOX (hbox), img, FALSE, FALSE, 0);
-  gtk_widget_set_halign (GTK_WIDGET (img), GTK_ALIGN_CENTER);
-  gtk_widget_set_valign (GTK_WIDGET (img), GTK_ALIGN_START);
-  gtk_widget_show (img);
-
-  label = g_object_new (GTK_TYPE_LABEL,
-                        "justify", GTK_JUSTIFY_LEFT,
-                        "label", _("List of applications that will be started "
-                                   "automatically on specific events like login, logout, shutdown, etc.\n"
-                                   "On login additionally all applications that were saved "
-                                   "on your last logout will be started.\n"
-                                   "Cursive applications belong to another desktop environment, "
-                                   "but you can still enable them if you want."),
-                        "xalign", 0.0f,
-                        NULL);
-  gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-  gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
-  gtk_widget_show (label);
-
   swin = g_object_new (GTK_TYPE_SCROLLED_WINDOW,
                        "hadjustment", NULL,
                        "vadjustment", NULL,
@@ -165,6 +150,10 @@ xfae_window_init (XfaeWindow *window)
                                    NULL);
   g_signal_connect (G_OBJECT (window->treeview), "button-press-event",
                     G_CALLBACK (xfae_window_button_press_event), window);
+  // fix buggy sizing behavior of gtk
+  g_signal_connect (G_OBJECT (window->treeview), "realize",
+                    G_CALLBACK(xfae_window_correct_treeview_column_size), NULL);
+
   gtk_container_add (GTK_CONTAINER (swin), window->treeview);
   gtk_widget_show (window->treeview);
 
@@ -177,6 +166,7 @@ xfae_window_init (XfaeWindow *window)
   window->selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (window->treeview));
   gtk_tree_selection_set_mode (window->selection, GTK_SELECTION_SINGLE);
 
+  // Column "toggled"
   column = g_object_new (GTK_TYPE_TREE_VIEW_COLUMN,
                          "reorderable", FALSE,
                          "resizable", FALSE,
@@ -189,7 +179,9 @@ xfae_window_init (XfaeWindow *window)
                                        "active", XFAE_MODEL_COLUMN_ENABLED,
                                        NULL);
   gtk_tree_view_append_column (GTK_TREE_VIEW (window->treeview), column);
+  gtk_tree_view_column_set_sort_column_id(column, XFAE_MODEL_COLUMN_ENABLED);
 
+  // Column "Program"
   column = g_object_new (GTK_TYPE_TREE_VIEW_COLUMN,
                          "reorderable", FALSE,
                          "resizable", FALSE,
@@ -210,8 +202,12 @@ xfae_window_init (XfaeWindow *window)
                                        "markup", XFAE_MODEL_COLUMN_NAME,
                                        NULL);
 
+  gtk_tree_view_column_set_sort_column_id(column, XFAE_MODEL_COLUMN_NAME);
+
   gtk_tree_view_append_column (GTK_TREE_VIEW (window->treeview), column);
 
+
+  // Column "Trigger"
   column = g_object_new (GTK_TYPE_TREE_VIEW_COLUMN,
                          "reorderable", FALSE,
                          "resizable", FALSE,
@@ -233,6 +229,8 @@ xfae_window_init (XfaeWindow *window)
                                        "text", XFAE_MODEL_RUN_HOOK,
                                        NULL);
   gtk_tree_view_append_column (GTK_TREE_VIEW (window->treeview), column);
+  gtk_tree_view_column_set_sort_column_id(column, XFAE_MODEL_RUN_HOOK);
+
   g_object_unref (model);
 
   bbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
@@ -240,17 +238,19 @@ xfae_window_init (XfaeWindow *window)
   gtk_style_context_add_class (gtk_widget_get_style_context (bbox), "inline-toolbar");
   gtk_widget_show (bbox);
 
-  button = gtk_button_new_with_label (_("Add"));
+  button = gtk_button_new ();
   img = gtk_image_new_from_icon_name ("list-add-symbolic", GTK_ICON_SIZE_BUTTON);
   gtk_button_set_image (GTK_BUTTON (button), img);
+  gtk_widget_set_tooltip_text (GTK_WIDGET (button), _("Add application"));
   g_signal_connect_swapped (G_OBJECT (button), "clicked",
                             G_CALLBACK (xfae_window_add), window);
   gtk_box_pack_start (GTK_BOX (bbox), button, FALSE, FALSE, 0);
   gtk_widget_show (button);
 
-  button = gtk_button_new_with_label (_("Remove"));
+  button = gtk_button_new ();
   img = gtk_image_new_from_icon_name ("list-remove-symbolic", GTK_ICON_SIZE_BUTTON);
   gtk_button_set_image (GTK_BUTTON (button), img);
+  gtk_widget_set_tooltip_text (GTK_WIDGET (button), _("Remove application"));
   g_signal_connect_swapped (G_OBJECT (button), "clicked",
                             G_CALLBACK (xfae_window_remove), window);
   gtk_box_pack_start (GTK_BOX (bbox), button, FALSE, FALSE, 0);
@@ -260,9 +260,10 @@ xfae_window_init (XfaeWindow *window)
                     G_CALLBACK (xfae_window_selection_changed), button);
   xfae_window_selection_changed (window->selection, button);
 
-  button = gtk_button_new_with_label (_("Edit"));
+  button = gtk_button_new ();
   img = gtk_image_new_from_icon_name ("document-edit-symbolic", GTK_ICON_SIZE_BUTTON);
   gtk_button_set_image (GTK_BUTTON (button), img);
+  gtk_widget_set_tooltip_text (GTK_WIDGET (button), _("Edit application"));
   g_signal_connect_swapped (G_OBJECT (button), "clicked",
                             G_CALLBACK (xfae_window_edit), window);
   gtk_box_pack_start (GTK_BOX (bbox), button, FALSE, FALSE, 0);
