@@ -137,12 +137,12 @@ main (int argc, char **argv)
 
   xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
 
-  have_display = gtk_init_with_args (&argc, &argv, "", option_entries, PACKAGE, NULL);
+  have_display = gtk_init_with_args (&argc, &argv, NULL, option_entries, PACKAGE, NULL);
 
   if (opt_version)
     {
       g_print ("%s %s (Xfce %s)\n\n", PACKAGE_NAME, PACKAGE_VERSION, xfce_version_string ());
-      g_print ("%s\n", "Copyright (c) 2004-2016");
+      g_print ("%s\n", "Copyright (c) 2004-2020");
       g_print ("\t%s\n\n", _("The Xfce development team. All rights reserved."));
       g_print ("%s\n", _("Written by Benedikt Meurer <benny@xfce.org>"));
       g_print ("%s\n\n", _("and Brian Tarricone <kelnos@xfce.org>."));
