@@ -8,16 +8,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- *                                                                              
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *                                                                              
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -60,18 +60,18 @@ typedef struct
 
 
 /* prototypes */
-static void	 ice_error_handler     (IceConn);
-static gboolean	 ice_process_messages  (GIOChannel  *channel,
-                                        GIOCondition condition,
-                                        gpointer     user_data);
-static gboolean	 ice_connection_accept (GIOChannel  *channel,
-                                        GIOCondition condition,
-                                        gpointer     watch_data);
-static FILE 	*ice_tmpfile           (char **name);
-static void	 ice_auth_add          (FILE *,
-                                        FILE *,
-                                        char *,
-                                        IceListenObj);
+static void ice_error_handler         (IceConn);
+static gboolean ice_process_messages  (GIOChannel  *channel,
+                                       GIOCondition condition,
+                                       gpointer     user_data);
+static gboolean ice_connection_accept (GIOChannel  *channel,
+                                       GIOCondition condition,
+                                       gpointer     watch_data);
+static FILE *ice_tmpfile              (char **name);
+static void ice_auth_add              (FILE *,
+                                       FILE *,
+                                       char *,
+                                       IceListenObj);
 
 static char *auth_cleanup_file;
 
@@ -134,6 +134,7 @@ ice_connection_watch (IceConn     ice_conn,
   GIOChannel  *channel;
   guint        watchid;
   gint         fd;
+  gint         ret;
 
   if (opening)
     {
@@ -146,7 +147,11 @@ ice_connection_watch (IceConn     ice_conn,
       /* Make sure we don't pass on these file descriptors to an
        * exec'd child process.
        */
-      fcntl (fd, F_SETFD, fcntl (fd, F_GETFD, 0) | FD_CLOEXEC);
+      ret = fcntl (fd, F_SETFD, fcntl (fd, F_GETFD, 0) | FD_CLOEXEC);
+      if (ret == -1)
+        {
+          perror ("ice_connection_watch: fcntl (fd, F_SETFD, fcntl (fd, F_GETFD, 0) | FD_CLOEXEC) failed");
+        }
 
       channel = g_io_channel_unix_new (fd);
       watchid = g_io_add_watch_full (channel, G_PRIORITY_DEFAULT,
@@ -206,7 +211,7 @@ ice_connection_accept (GIOChannel  *channel,
           IceCloseConnection (ice_conn);
         }
     }
-  
+
   return TRUE;
 }
 
@@ -297,6 +302,7 @@ ice_setup_listeners (int           num_listeners,
   FILE       *setup_fp;
   int         fd;
   int         n;
+  int         ret;
 
   IceSetIOErrorHandler (ice_error_handler);
   IceAddConnectionWatch (ice_connection_watch, manager);
@@ -321,7 +327,11 @@ ice_setup_listeners (int           num_listeners,
       /* Make sure we don't pass on these file descriptors to an
        * exec'd child process.
        */
-      fcntl (fd, F_SETFD, fcntl (fd, F_GETFD, 0) | FD_CLOEXEC);
+      ret = fcntl (fd, F_SETFD, fcntl (fd, F_GETFD, 0) | FD_CLOEXEC);
+      if (ret == -1)
+        {
+          perror ("ice_setup_listeners: fcntl (fd, F_SETFD, fcntl (fd, F_GETFD, 0) | FD_CLOEXEC) failed");
+        }
 
       channel = g_io_channel_unix_new (fd);
       g_io_add_watch (channel, G_IO_ERR | G_IO_HUP | G_IO_IN,
