@@ -88,7 +88,6 @@ static void name_lost (GDBusConnection *connection,
 static void
 setup_environment (void)
 {
-  const gchar *lang;
   const gchar *sm;
   gchar       *authfile;
   int          fd;
@@ -108,14 +107,6 @@ setup_environment (void)
   /* pass correct DISPLAY to children, in case of --display in argv */
   g_setenv ("DISPLAY", gdk_display_get_name (gdk_display_get_default ()), TRUE);
 
-  /* this is for compatibility with the GNOME Display Manager */
-  lang = g_getenv ("GDM_LANG");
-  if (lang != NULL && strlen (lang) > 0)
-    {
-      g_setenv ("LANG", lang, TRUE);
-      g_unsetenv ("GDM_LANG");
-    }
-
   /* check access to $ICEAUTHORITY or $HOME/.ICEauthority if unset */
   if (g_getenv ("ICEAUTHORITY"))
     authfile = g_strdup (g_getenv ("ICEAUTHORITY"));
@@ -327,7 +318,7 @@ main (int argc, char **argv)
   /* install required signal handlers */
   signal (SIGPIPE, SIG_IGN);
 
-  if (!gtk_init_with_args (&argc, &argv, "", option_entries, GETTEXT_PACKAGE, &error))
+  if (!gtk_init_with_args (&argc, &argv, NULL, option_entries, GETTEXT_PACKAGE, &error))
     {
       g_print ("%s: %s.\n", G_LOG_DOMAIN, error->message);
       g_print (_("Type '%s --help' for usage."), G_LOG_DOMAIN);
@@ -339,7 +330,7 @@ main (int argc, char **argv)
   if (opt_version)
     {
       g_print ("%s %s (Xfce %s)\n\n", G_LOG_DOMAIN, PACKAGE_VERSION, xfce_version_string ());
-      g_print ("%s\n", "Copyright (c) 2003-2016");
+      g_print ("%s\n", "Copyright (c) 2003-2020");
       g_print ("\t%s\n\n", _("The Xfce development team. All rights reserved."));
       g_print (_("Please report bugs to <%s>."), PACKAGE_BUGREPORT);
       g_print ("\n");
@@ -366,5 +357,7 @@ main (int argc, char **argv)
 
   gtk_main ();
 
+  xfsm_startup_shutdown ();
+
   return EXIT_SUCCESS;
 }
