@@ -39,7 +39,7 @@ struct _XfsmFadeout
 {
 #ifdef GDK_WINDOWING_X11
   Display *xdisplay;
-  GSList  *xwindows;
+  Window  *xwindow;
 #endif
 };
 
@@ -63,6 +63,7 @@ xfsm_x11_fadeout_new_window (GdkDisplay *display,
   gulong                mask = 0;
   gulong                opacity;
   gboolean              composited;
+  gint                  scale;
 
   gdk_error_trap_push ();
 
@@ -77,6 +78,10 @@ xfsm_x11_fadeout_new_window (GdkDisplay *display,
 
   cursor = gdk_cursor_new_for_display (display, GDK_WATCH);
 
+  scale = gdk_window_get_scale_factor (root);
+  width *= scale;
+  height *= scale;
+
   if (!composited)
     {
       /* create a copy of root window before showing the fadeout */
@@ -144,22 +149,13 @@ xfsm_fadeout_new (GdkDisplay *display)
 {
   XfsmFadeout     *fadeout;
   GdkScreen       *screen;
-#ifdef GDK_WINDOWING_X11
-  Window           xwindow;
-#endif
-  gint             n;
 
   fadeout = g_slice_new0 (XfsmFadeout);
 
 #ifdef GDK_WINDOWING_X11
   fadeout->xdisplay = gdk_x11_display_get_xdisplay (display);
-
-  for (n = 0; n < XScreenCount (fadeout->xdisplay); ++n)
-    {
-      screen = gdk_display_get_screen (display, n);
-      xwindow = xfsm_x11_fadeout_new_window (display, screen);
-      fadeout->xwindows = g_slist_prepend (fadeout->xwindows, GINT_TO_POINTER (xwindow));
-    }
+  screen = gdk_display_get_default_screen (display);
+  fadeout->xwindow = GINT_TO_POINTER (xfsm_x11_fadeout_new_window (display, screen));
 #endif
 
   return fadeout;
@@ -167,25 +163,12 @@ xfsm_fadeout_new (GdkDisplay *display)
 
 
 
-#ifdef GDK_WINDOWING_X11
-static void
-xfsm_fadeout_destroy_foreach (gpointer data, gpointer user_data)
-{
-  XfsmFadeout *fadeout = user_data;
-  Window       xwindow = GPOINTER_TO_INT (data);
-
-  XDestroyWindow (fadeout->xdisplay, xwindow);
-}
-#endif
-
-
-
 void
 xfsm_fadeout_destroy (XfsmFadeout *fadeout)
 {
 #ifdef GDK_WINDOWING_X11
   gdk_error_trap_push ();
-  g_slist_foreach (fadeout->xwindows, xfsm_fadeout_destroy_foreach, fadeout);
+  XDestroyWindow (fadeout->xdisplay, GPOINTER_TO_INT (fadeout->xwindow));
   gdk_flush ();
   gdk_error_trap_pop_ignored ();
 #endif
