@@ -53,9 +53,6 @@
 #ifdef HAVE_SIGNAL_H
 #include <signal.h>
 #endif
-#ifdef HAVE_SYS_SYSCTL_H
-#include <sys/sysctl.h>
-#endif
 
 #include <gio/gio.h>
 #include <libxfce4util/libxfce4util.h>
@@ -76,6 +73,9 @@
 
 #if defined(__DragonFly__) || defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__)
 #define __BACKEND_TYPE_BSD__ 1
+#ifdef HAVE_SYS_SYSCTL_H
+#include <sys/sysctl.h>
+#endif
 #endif
 
 #define POLKIT_AUTH_SHUTDOWN_XFSM     "org.xfce.session.xfsm-shutdown-helper"
@@ -347,6 +347,8 @@ lock_screen (GError **error)
       /* sleep 2 seconds so locking has time to startup */
       g_usleep (G_USEC_PER_SEC * 2);
     }
+  else
+    g_set_error (error, 1, 0, "Failed to lock the screen.");
 
   g_object_unref (G_OBJECT (saver));
 
@@ -410,6 +412,7 @@ xfsm_shutdown_fallback_try_action (XfsmShutdownType   type,
         return FALSE;
       break;
     default:
+      g_set_error (error, 1, 0, "Unknown shutdown type %d", type);
       return FALSE;
   }
 
@@ -429,6 +432,10 @@ xfsm_shutdown_fallback_try_action (XfsmShutdownType   type,
 
   g_free (command);
 #endif
+  if (!ret)
+    {
+      g_set_error (error, 1, 0, "Failed to %s (%s)", xfsm_helper_action, cmd);
+    }
   return ret;
 }
 
